@@ -10,11 +10,12 @@ from ..properties import Constant
 from ..properties.property import Property
 from ..structures.cast_operator import CastOperator
 from ..structures.distinct import Distinct
+from ..structures.case import Case
 
 
 class Count(BaseFunction):
     obj: Literal['functions.Count'] = 'functions.Count'
-    property: Union[Property, BaseFunction, Constant, CastOperator, Distinct]
+    property: Union[Property, BaseFunction, Constant, CastOperator, Distinct, Case]
     alias: str = None
 
     def to_sql(self) -> str:
